from ai.stigmer.commons.apiresource import field_options_pb2 as _field_options_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SwitchTaskConfig(_message.Message):
    __slots__ = ("cases",)
    CASES_FIELD_NUMBER: _ClassVar[int]
    cases: _containers.RepeatedCompositeFieldContainer[SwitchCase]
    def __init__(self, cases: _Optional[_Iterable[_Union[SwitchCase, _Mapping]]] = ...) -> None: ...

class SwitchCase(_message.Message):
    __slots__ = ("name", "when", "then")
    NAME_FIELD_NUMBER: _ClassVar[int]
    WHEN_FIELD_NUMBER: _ClassVar[int]
    THEN_FIELD_NUMBER: _ClassVar[int]
    name: str
    when: str
    then: str
    def __init__(self, name: _Optional[str] = ..., when: _Optional[str] = ..., then: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/iam/apikey/v1/command.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/iam/apikey/v1/command.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.apikey.v1 import api_pb2 as ai_dot_stigmer_dot_iam_dot_apikey_dot_v1_dot_api__pb2
from ai.stigmer.iam.apikey.v1 import io_pb2 as ai_dot_stigmer_dot_iam_dot_apikey_dot_v1_dot_io__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ai/stigmer/iam/apikey/v1/command.proto\x12\x18\x61i.stigmer.iam.apikey.v1\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\"ai/stigmer/iam/apikey/v1/api.proto\x1a!ai/stigmer/iam/apikey/v1/io.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto2\xfa\x02\n\x17\x41piKeyCommandController\x12R\n\x06\x63reate\x12 .ai.stigmer.iam.apikey.v1.ApiKey\x1a .ai.stigmer.iam.apikey.v1.ApiKey\"\x04\xd0\xb8\x18\x01\x12\x83\x01\n\x06update\x12 .ai.stigmer.iam.apikey.v1.ApiKey\x1a .ai.stigmer.iam.apikey.v1.ApiKey\"5\xc2\xb8\x18\x31\x08\x04\x10\x0c\"\x0bmetadata.id*\x1eunauthorized to update api key\x12\x7f\n\x06\x64\x65lete\x12\".ai.stigmer.iam.apikey.v1.ApiKeyId\x1a .ai.stigmer.iam.apikey.v1.ApiKey\"/\xc2\xb8\x18+\x08\x02\x10\x0c\"\x05value*\x1eunauthorized to delete api key\x1a\x04\xa0\xff+\x0c\x42\xb1\x01\n\x1c\x63om.ai.stigmer.iam.apikey.v1B\x0c\x43ommandProtoP\x01\xa2\x02\x04\x41SIA\xaa\x02\x18\x41i.Stigmer.Iam.Apikey.V1\xca\x02\x18\x41i\\Stigmer\\Iam\\Apikey\\V1\xe2\x02$Ai\\Stigmer\\Iam\\Apikey\\V1\\GPBMetadata\xea\x02\x1c\x41i::Stigmer::Iam::Apikey::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.iam.apikey.v1.command_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.ai.stigmer.iam.apikey.v1B\014CommandProtoP\001\242\002\004ASIA\252\002\030Ai.Stigmer.Iam.Apikey.V1\312\002\030Ai\\Stigmer\\Iam\\Apikey\\V1\342\002$Ai\\Stigmer\\Iam\\Apikey\\V1\\GPBMetadata\352\002\034Ai::Stigmer::Iam::Apikey::V1'
  _globals['_APIKEYCOMMANDCONTROLLER']._loaded_options = None
  _globals['_APIKEYCOMMANDCONTROLLER']._serialized_options = b'\240\377+\014'
  _globals['_APIKEYCOMMANDCONTROLLER'].methods_by_name['create']._loaded_options = None
  _globals['_APIKEYCOMMANDCONTROLLER'].methods_by_name['create']._serialized_options = b'\320\270\030\001'
  _globals['_APIKEYCOMMANDCONTROLLER'].methods_by_name['update']._loaded_options = None
  _globals['_APIKEYCOMMANDCONTROLLER'].methods_by_name['update']._serialized_options = b'\302\270\0301\010\004\020\014\"\013metadata.id*\036unauthorized to update api key'
  _globals['_APIKEYCOMMANDCONTROLLER'].methods_by_name['delete']._loaded_options = None
  _globals['_APIKEYCOMMANDCONTROLLER'].methods_by_name['delete']._serialized_options = b'\302\270\030+\010\002\020\014\"\005value*\036unauthorized to delete api key'
  _globals['_APIKEYCOMMANDCONTROLLER']._serialized_start=265
  _globals['_APIKEYCOMMANDCONTROLLER']._serialized_end=643
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflowinstance/v1/io.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflowinstance/v1/io.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.workflowinstance.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_workflowinstance_dot_v1_dot_api__pb2
from ai.stigmer.commons.rpc import pagination_pb2 as ai_dot_stigmer_dot_commons_dot_rpc_dot_pagination__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/ai/stigmer/agentic/workflowinstance/v1/io.proto\x12&ai.stigmer.agentic.workflowinstance.v1\x1a\x30\x61i/stigmer/agentic/workflowinstance/v1/api.proto\x1a\'ai/stigmer/commons/rpc/pagination.proto\x1a\x1b\x62uf/validate/validate.proto\"2\n\x12WorkflowInstanceId\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\"\x8f\x01\n%GetWorkflowInstancesByWorkflowRequest\x12\'\n\x0bworkflow_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\nworkflowId\x12=\n\tpage_info\x18\x02 \x01(\x0b\x32 .ai.stigmer.commons.rpc.PageInfoR\x08pageInfo\"\x8b\x01\n\x14WorkflowInstanceList\x12\x1f\n\x0btotal_pages\x18\x01 \x01(\x05R\ntotalPages\x12R\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x38.ai.stigmer.agentic.workflowinstance.v1.WorkflowInstanceR\x07\x65ntriesB\xf2\x01\n*com.ai.stigmer.agentic.workflowinstance.v1B\x07IoProtoP\x01\xa2\x02\x04\x41SAW\xaa\x02&Ai.Stigmer.Agentic.Workflowinstance.V1\xca\x02&Ai\\Stigmer\\Agentic\\Workflowinstance\\V1\xe2\x02\x32\x41i\\Stigmer\\Agentic\\Workflowinstance\\V1\\GPBMetadata\xea\x02*Ai::Stigmer::Agentic::Workflowinstance::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflowinstance.v1.io_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*com.ai.stigmer.agentic.workflowinstance.v1B\007IoProtoP\001\242\002\004ASAW\252\002&Ai.Stigmer.Agentic.Workflowinstance.V1\312\002&Ai\\Stigmer\\Agentic\\Workflowinstance\\V1\342\0022Ai\\Stigmer\\Agentic\\Workflowinstance\\V1\\GPBMetadata\352\002*Ai::Stigmer::Agentic::Workflowinstance::V1'
  _globals['_WORKFLOWINSTANCEID'].fields_by_name['value']._loaded_options = None
  _globals['_WORKFLOWINSTANCEID'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETWORKFLOWINSTANCESBYWORKFLOWREQUEST'].fields_by_name['workflow_id']._loaded_options = None
  _globals['_GETWORKFLOWINSTANCESBYWORKFLOWREQUEST'].fields_by_name['workflow_id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_WORKFLOWINSTANCEID']._serialized_start=211
  _globals['_WORKFLOWINSTANCEID']._serialized_end=261
  _globals['_GETWORKFLOWINSTANCESBYWORKFLOWREQUEST']._serialized_start=264
  _globals['_GETWORKFLOWINSTANCESBYWORKFLOWREQUEST']._serialized_end=407
  _globals['_WORKFLOWINSTANCELIST']._serialized_start=410
  _globals['_WORKFLOWINSTANCELIST']._serialized_end=549
# @@protoc_insertion_point(module_scope)



from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class WorkspaceSource(_message.Message):
    __slots__ = ("git_repo", "local_path")
    GIT_REPO_FIELD_NUMBER: _ClassVar[int]
    LOCAL_PATH_FIELD_NUMBER: _ClassVar[int]
    git_repo: GitRepoSource
    local_path: LocalPathSource
    def __init__(self, git_repo: _Optional[_Union[GitRepoSource, _Mapping]] = ..., local_path: _Optional[_Union[LocalPathSource, _Mapping]] = ...) -> None: ...

class WorkspaceEntry(_message.Message):
    __slots__ = ("name", "source")
    NAME_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    name: str
    source: WorkspaceSource
    def __init__(self, name: _Optional[str] = ..., source: _Optional[_Union[WorkspaceSource, _Mapping]] = ...) -> None: ...

class LocalPathSource(_message.Message):
    __slots__ = ("path",)
    PATH_FIELD_NUMBER: _ClassVar[int]
    path: str
    def __init__(self, path: _Optional[str] = ...) -> None: ...

class GitRepoSource(_message.Message):
    __slots__ = ("url", "branch", "commit", "depth")
    URL_FIELD_NUMBER: _ClassVar[int]
    BRANCH_FIELD_NUMBER: _ClassVar[int]
    COMMIT_FIELD_NUMBER: _ClassVar[int]
    DEPTH_FIELD_NUMBER: _ClassVar[int]
    url: str
    branch: str
    commit: str
    depth: int
    def __init__(self, url: _Optional[str] = ..., branch: _Optional[str] = ..., commit: _Optional[str] = ..., depth: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/iam/identityaccount/v1/io.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/iam/identityaccount/v1/io.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.rpc import pagination_pb2 as ai_dot_stigmer_dot_commons_dot_rpc_dot_pagination__pb2
from ai.stigmer.iam.identityaccount.v1 import api_pb2 as ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_api__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*ai/stigmer/iam/identityaccount/v1/io.proto\x12!ai.stigmer.iam.identityaccount.v1\x1a\'ai/stigmer/commons/rpc/pagination.proto\x1a+ai/stigmer/iam/identityaccount/v1/api.proto\x1a\x1b\x62uf/validate/validate.proto\"`\n\x10IdentityAccounts\x12L\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x32.ai.stigmer.iam.identityaccount.v1.IdentityAccountR\x07\x65ntries\"1\n\x11IdentityAccountId\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\"4\n\x14IdentityAccountEmail\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\"%\n\x05IdpId\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\"\x84\x01\n\x1cListWithIdentityAccountIdReq\x12.\n\x13identity_account_id\x18\x01 \x01(\tR\x11identityAccountId\x12\x34\n\x04page\x18\x02 \x01(\x0b\x32 .ai.stigmer.commons.rpc.PageInfoR\x04page\"\x85\x01\n\x14IdentityAccountsList\x12\x1f\n\x0btotal_pages\x18\x01 \x01(\x05R\ntotalPages\x12L\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x32.ai.stigmer.iam.identityaccount.v1.IdentityAccountR\x07\x65ntries\"]\n\x13ListWithIdentityOrg\x12\x10\n\x03org\x18\x01 \x01(\tR\x03org\x12\x34\n\x04page\x18\x02 \x01(\x0b\x32 .ai.stigmer.commons.rpc.PageInfoR\x04pageB\xd9\x01\n%com.ai.stigmer.iam.identityaccount.v1B\x07IoProtoP\x01\xa2\x02\x04\x41SII\xaa\x02!Ai.Stigmer.Iam.Identityaccount.V1\xca\x02!Ai\\Stigmer\\Iam\\Identityaccount\\V1\xe2\x02-Ai\\Stigmer\\Iam\\Identityaccount\\V1\\GPBMetadata\xea\x02%Ai::Stigmer::Iam::Identityaccount::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.iam.identityaccount.v1.io_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%com.ai.stigmer.iam.identityaccount.v1B\007IoProtoP\001\242\002\004ASII\252\002!Ai.Stigmer.Iam.Identityaccount.V1\312\002!Ai\\Stigmer\\Iam\\Identityaccount\\V1\342\002-Ai\\Stigmer\\Iam\\Identityaccount\\V1\\GPBMetadata\352\002%Ai::Stigmer::Iam::Identityaccount::V1'
  _globals['_IDENTITYACCOUNTID'].fields_by_name['value']._loaded_options = None
  _globals['_IDENTITYACCOUNTID'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_IDENTITYACCOUNTEMAIL'].fields_by_name['value']._loaded_options = None
  _globals['_IDENTITYACCOUNTEMAIL'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_IDPID'].fields_by_name['value']._loaded_options = None
  _globals['_IDPID'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_IDENTITYACCOUNTS']._serialized_start=196
  _globals['_IDENTITYACCOUNTS']._serialized_end=292
  _globals['_IDENTITYACCOUNTID']._serialized_start=294
  _globals['_IDENTITYACCOUNTID']._serialized_end=343
  _globals['_IDENTITYACCOUNTEMAIL']._serialized_start=345
  _globals['_IDENTITYACCOUNTEMAIL']._serialized_end=397
  _globals['_IDPID']._serialized_start=399
  _globals['_IDPID']._serialized_end=436
  _globals['_LISTWITHIDENTITYACCOUNTIDREQ']._serialized_start=439
  _globals['_LISTWITHIDENTITYACCOUNTIDREQ']._serialized_end=571
  _globals['_IDENTITYACCOUNTSLIST']._serialized_start=574
  _globals['_IDENTITYACCOUNTSLIST']._serialized_end=707
  _globals['_LISTWITHIDENTITYORG']._serialized_start=709
  _globals['_LISTWITHIDENTITYORG']._serialized_end=802
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/platform/github/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/platform/github/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+ai/stigmer/platform/github/v1/service.proto\x12\x1d\x61i.stigmer.platform.github.v1\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto\x1a\x1b\x62uf/validate/validate.proto\"I\n\x1bGetOAuthAuthorizeUrlRequest\x12*\n\x0credirect_uri\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0bredirectUri\"Y\n\x1cGetOAuthAuthorizeUrlResponse\x12#\n\rauthorize_url\x18\x01 \x01(\tR\x0c\x61uthorizeUrl\x12\x14\n\x05state\x18\x02 \x01(\tR\x05state\"\x82\x01\n\x18\x45xchangeOAuthCodeRequest\x12\x1b\n\x04\x63ode\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x04\x63ode\x12\x1d\n\x05state\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x05state\x12*\n\x0credirect_uri\x18\x03 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0bredirectUri\"s\n\x19\x45xchangeOAuthCodeResponse\x12!\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\tR\x0b\x61\x63\x63\x65ssToken\x12\x1d\n\ntoken_type\x18\x02 \x01(\tR\ttokenType\x12\x14\n\x05scope\x18\x03 \x01(\tR\x05scope2\xb6\x02\n\rGitHubService\x12\x95\x01\n\x14getOAuthAuthorizeUrl\x12:.ai.stigmer.platform.github.v1.GetOAuthAuthorizeUrlRequest\x1a;.ai.stigmer.platform.github.v1.GetOAuthAuthorizeUrlResponse\"\x04\xd0\xb8\x18\x01\x12\x8c\x01\n\x11\x65xchangeOAuthCode\x12\x37.ai.stigmer.platform.github.v1.ExchangeOAuthCodeRequest\x1a\x38.ai.stigmer.platform.github.v1.ExchangeOAuthCodeResponse\"\x04\xd0\xb8\x18\x01\x42\xca\x01\n!com.ai.stigmer.platform.github.v1B\x0cServiceProtoP\x01\xa2\x02\x04\x41SPG\xaa\x02\x1d\x41i.Stigmer.Platform.Github.V1\xca\x02\x1d\x41i\\Stigmer\\Platform\\Github\\V1\xe2\x02)Ai\\Stigmer\\Platform\\Github\\V1\\GPBMetadata\xea\x02!Ai::Stigmer::Platform::Github::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.platform.github.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.ai.stigmer.platform.github.v1B\014ServiceProtoP\001\242\002\004ASPG\252\002\035Ai.Stigmer.Platform.Github.V1\312\002\035Ai\\Stigmer\\Platform\\Github\\V1\342\002)Ai\\Stigmer\\Platform\\Github\\V1\\GPBMetadata\352\002!Ai::Stigmer::Platform::Github::V1'
  _globals['_GETOAUTHAUTHORIZEURLREQUEST'].fields_by_name['redirect_uri']._loaded_options = None
  _globals['_GETOAUTHAUTHORIZEURLREQUEST'].fields_by_name['redirect_uri']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_EXCHANGEOAUTHCODEREQUEST'].fields_by_name['code']._loaded_options = None
  _globals['_EXCHANGEOAUTHCODEREQUEST'].fields_by_name['code']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_EXCHANGEOAUTHCODEREQUEST'].fields_by_name['state']._loaded_options = None
  _globals['_EXCHANGEOAUTHCODEREQUEST'].fields_by_name['state']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_EXCHANGEOAUTHCODEREQUEST'].fields_by_name['redirect_uri']._loaded_options = None
  _globals['_EXCHANGEOAUTHCODEREQUEST'].fields_by_name['redirect_uri']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_GITHUBSERVICE'].methods_by_name['getOAuthAuthorizeUrl']._loaded_options = None
  _globals['_GITHUBSERVICE'].methods_by_name['getOAuthAuthorizeUrl']._serialized_options = b'\320\270\030\001'
  _globals['_GITHUBSERVICE'].methods_by_name['exchangeOAuthCode']._loaded_options = None
  _globals['_GITHUBSERVICE'].methods_by_name['exchangeOAuthCode']._serialized_options = b'\320\270\030\001'
  _globals['_GETOAUTHAUTHORIZEURLREQUEST']._serialized_start=174
  _globals['_GETOAUTHAUTHORIZEURLREQUEST']._serialized_end=247
  _globals['_GETOAUTHAUTHORIZEURLRESPONSE']._serialized_start=249
  _globals['_GETOAUTHAUTHORIZEURLRESPONSE']._serialized_end=338
  _globals['_EXCHANGEOAUTHCODEREQUEST']._serialized_start=341
  _globals['_EXCHANGEOAUTHCODEREQUEST']._serialized_end=471
  _globals['_EXCHANGEOAUTHCODERESPONSE']._serialized_start=473
  _globals['_EXCHANGEOAUTHCODERESPONSE']._serialized_end=588
  _globals['_GITHUBSERVICE']._serialized_start=591
  _globals['_GITHUBSERVICE']._serialized_end=901
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/commons/apiresource/metadata.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/commons/apiresource/metadata.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import enum_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_enum__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-ai/stigmer/commons/apiresource/metadata.proto\x12\x1e\x61i.stigmer.commons.apiresource\x1a)ai/stigmer/commons/apiresource/enum.proto\x1a\x1b\x62uf/validate/validate.proto\"\xe6\x04\n\x13\x41piResourceMetadata\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12\x0e\n\x02id\x18\x03 \x01(\tR\x02id\x12\x10\n\x03org\x18\x04 \x01(\tR\x03org\x12_\n\nvisibility\x18\x05 \x01(\x0e\x32\x35.ai.stigmer.commons.apiresource.ApiResourceVisibilityB\x08\xbaH\x05\x82\x01\x02\x10\x01R\nvisibility\x12W\n\x06labels\x18\x06 \x03(\x0b\x32?.ai.stigmer.commons.apiresource.ApiResourceMetadata.LabelsEntryR\x06labels\x12\x66\n\x0b\x61nnotations\x18\x07 \x03(\x0b\x32\x44.ai.stigmer.commons.apiresource.ApiResourceMetadata.AnnotationsEntryR\x0b\x61nnotations\x12\x12\n\x04tags\x18\x08 \x03(\tR\x04tags\x12T\n\x07version\x18\t \x01(\x0b\x32:.ai.stigmer.commons.apiresource.ApiResourceMetadataVersionR\x07version\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a>\n\x10\x41nnotationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"v\n\x1a\x41piResourceMetadataVersion\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12.\n\x13previous_version_id\x18\x03 \x01(\tR\x11previousVersionIdB\xcf\x01\n\"com.ai.stigmer.commons.apiresourceB\rMetadataProtoP\x01\xa2\x02\x04\x41SCA\xaa\x02\x1e\x41i.Stigmer.Commons.Apiresource\xca\x02\x1e\x41i\\Stigmer\\Commons\\Apiresource\xe2\x02*Ai\\Stigmer\\Commons\\Apiresource\\GPBMetadata\xea\x02!Ai::Stigmer::Commons::Apiresourceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.commons.apiresource.metadata_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.ai.stigmer.commons.apiresourceB\rMetadataProtoP\001\242\002\004ASCA\252\002\036Ai.Stigmer.Commons.Apiresource\312\002\036Ai\\Stigmer\\Commons\\Apiresource\342\002*Ai\\Stigmer\\Commons\\Apiresource\\GPBMetadata\352\002!Ai::Stigmer::Commons::Apiresource'
  _globals['_APIRESOURCEMETADATA_LABELSENTRY']._loaded_options = None
  _globals['_APIRESOURCEMETADATA_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_APIRESOURCEMETADATA_ANNOTATIONSENTRY']._loaded_options = None
  _globals['_APIRESOURCEMETADATA_ANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_APIRESOURCEMETADATA'].fields_by_name['visibility']._loaded_options = None
  _globals['_APIRESOURCEMETADATA'].fields_by_name['visibility']._serialized_options = b'\272H\005\202\001\002\020\001'
  _globals['_APIRESOURCEMETADATA']._serialized_start=154
  _globals['_APIRESOURCEMETADATA']._serialized_end=768
  _globals['_APIRESOURCEMETADATA_LABELSENTRY']._serialized_start=647
  _globals['_APIRESOURCEMETADATA_LABELSENTRY']._serialized_end=704
  _globals['_APIRESOURCEMETADATA_ANNOTATIONSENTRY']._serialized_start=706
  _globals['_APIRESOURCEMETADATA_ANNOTATIONSENTRY']._serialized_end=768
  _globals['_APIRESOURCEMETADATAVERSION']._serialized_start=770
  _globals['_APIRESOURCEMETADATAVERSION']._serialized_end=888
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/tenancy/project/v1/status.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/tenancy/project/v1/status.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2
from ai.stigmer.commons.apiresource import status_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*ai/stigmer/tenancy/project/v1/status.proto\x12\x1d\x61i.stigmer.tenancy.project.v1\x1a\'ai/stigmer/commons/apiresource/io.proto\x1a+ai/stigmer/commons/apiresource/status.proto\"\x87\x02\n\x15ReconciliationSummary\x12N\n\x07\x63reated\x18\x01 \x03(\x0b\x32\x34.ai.stigmer.commons.apiresource.ApiResourceReferenceR\x07\x63reated\x12N\n\x07updated\x18\x02 \x03(\x0b\x32\x34.ai.stigmer.commons.apiresource.ApiResourceReferenceR\x07updated\x12N\n\x07\x64\x65leted\x18\x03 \x03(\x0b\x32\x34.ai.stigmer.commons.apiresource.ApiResourceReferenceR\x07\x64\x65leted\"\xbe\x01\n\rProjectStatus\x12\x65\n\x13last_reconciliation\x18\x01 \x01(\x0b\x32\x34.ai.stigmer.tenancy.project.v1.ReconciliationSummaryR\x12lastReconciliation\x12\x46\n\x05\x61udit\x18\x63 \x01(\x0b\x32\x30.ai.stigmer.commons.apiresource.ApiResourceAuditR\x05\x61uditB\xc9\x01\n!com.ai.stigmer.tenancy.project.v1B\x0bStatusProtoP\x01\xa2\x02\x04\x41STP\xaa\x02\x1d\x41i.Stigmer.Tenancy.Project.V1\xca\x02\x1d\x41i\\Stigmer\\Tenancy\\Project\\V1\xe2\x02)Ai\\Stigmer\\Tenancy\\Project\\V1\\GPBMetadata\xea\x02!Ai::Stigmer::Tenancy::Project::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.tenancy.project.v1.status_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.ai.stigmer.tenancy.project.v1B\013StatusProtoP\001\242\002\004ASTP\252\002\035Ai.Stigmer.Tenancy.Project.V1\312\002\035Ai\\Stigmer\\Tenancy\\Project\\V1\342\002)Ai\\Stigmer\\Tenancy\\Project\\V1\\GPBMetadata\352\002!Ai::Stigmer::Tenancy::Project::V1'
  _globals['_RECONCILIATIONSUMMARY']._serialized_start=164
  _globals['_RECONCILIATIONSUMMARY']._serialized_end=427
  _globals['_PROJECTSTATUS']._serialized_start=430
  _globals['_PROJECTSTATUS']._serialized_end=620
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/tenancy/organization/v1/api.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/tenancy/organization/v1/api.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import metadata_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_metadata__pb2
from ai.stigmer.commons.apiresource import status_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_status__pb2
from ai.stigmer.tenancy.organization.v1 import spec_pb2 as ai_dot_stigmer_dot_tenancy_dot_organization_dot_v1_dot_spec__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ai/stigmer/tenancy/organization/v1/api.proto\x12\"ai.stigmer.tenancy.organization.v1\x1a-ai/stigmer/commons/apiresource/metadata.proto\x1a+ai/stigmer/commons/apiresource/status.proto\x1a-ai/stigmer/tenancy/organization/v1/spec.proto\x1a\x1b\x62uf/validate/validate.proto\"\xdd\x05\n\x0cOrganization\x12=\n\x0b\x61pi_version\x18\x01 \x01(\tB\x1c\xbaH\x19r\x17\n\x15tenancy.stigmer.ai/v1R\napiVersion\x12\'\n\x04kind\x18\x02 \x01(\tB\x13\xbaH\x10r\x0e\n\x0cOrganizationR\x04kind\x12\xca\x03\n\x08metadata\x18\x03 \x01(\x0b\x32\x33.ai.stigmer.commons.apiresource.ApiResourceMetadataB\xf8\x02\xbaH\xf4\x02\xba\x01\x81\x01\n\x13metadata.slug.chars\x12Gmetadata.slug: Only lowercase letters, numbers, and hyphens are allowed\x1a!this.slug.matches(\'^[a-z0-9-]+$\')\xba\x01h\n\x13metadata.slug.start\x12\x31metadata.slug: Must start with a lowercase letter\x1a\x1ethis.slug.matches(\'^[a-z].*$\')\xba\x01~\n\x14metadata.slug.length\x12\x37metadata.slug: Must be between 2 and 15 characters long\x1a-size(this.slug) >= 2 && size(this.slug) <= 15\xc8\x01\x01R\x08metadata\x12H\n\x04spec\x18\x04 \x01(\x0b\x32\x34.ai.stigmer.tenancy.organization.v1.OrganizationSpecR\x04spec\x12N\n\x06status\x18\x05 \x01(\x0b\x32\x36.ai.stigmer.commons.apiresource.ApiResourceAuditStatusR\x06statusB\xdf\x01\n&com.ai.stigmer.tenancy.organization.v1B\x08\x41piProtoP\x01\xa2\x02\x04\x41STO\xaa\x02\"Ai.Stigmer.Tenancy.Organization.V1\xca\x02\"Ai\\Stigmer\\Tenancy\\Organization\\V1\xe2\x02.Ai\\Stigmer\\Tenancy\\Organization\\V1\\GPBMetadata\xea\x02&Ai::Stigmer::Tenancy::Organization::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.tenancy.organization.v1.api_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&com.ai.stigmer.tenancy.organization.v1B\010ApiProtoP\001\242\002\004ASTO\252\002\"Ai.Stigmer.Tenancy.Organization.V1\312\002\"Ai\\Stigmer\\Tenancy\\Organization\\V1\342\002.Ai\\Stigmer\\Tenancy\\Organization\\V1\\GPBMetadata\352\002&Ai::Stigmer::Tenancy::Organization::V1'
  _globals['_ORGANIZATION'].fields_by_name['api_version']._loaded_options = None
  _globals['_ORGANIZATION'].fields_by_name['api_version']._serialized_options = b'\272H\031r\027\n\025tenancy.stigmer.ai/v1'
  _globals['_ORGANIZATION'].fields_by_name['kind']._loaded_options = None
  _globals['_ORGANIZATION'].fields_by_name['kind']._serialized_options = b'\272H\020r\016\n\014Organization'
  _globals['_ORGANIZATION'].fields_by_name['metadata']._loaded_options = None
  _globals['_ORGANIZATION'].fields_by_name['metadata']._serialized_options = b'\272H\364\002\272\001\201\001\n\023metadata.slug.chars\022Gmetadata.slug: Only lowercase letters, numbers, and hyphens are allowed\032!this.slug.matches(\'^[a-z0-9-]+$\')\272\001h\n\023metadata.slug.start\0221metadata.slug: Must start with a lowercase letter\032\036this.slug.matches(\'^[a-z].*$\')\272\001~\n\024metadata.slug.length\0227metadata.slug: Must be between 2 and 15 characters long\032-size(this.slug) >= 2 && size(this.slug) <= 15\310\001\001'
  _globals['_ORGANIZATION']._serialized_start=253
  _globals['_ORGANIZATION']._serialized_end=986
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/commons/apiresource/io.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/commons/apiresource/io.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource.apiresourcekind import api_resource_kind_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_apiresourcekind_dot_api__resource__kind__pb2
from ai.stigmer.commons.apiresource import enum_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_enum__pb2
from ai.stigmer.commons.rpc import pagination_pb2 as ai_dot_stigmer_dot_commons_dot_rpc_dot_pagination__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'ai/stigmer/commons/apiresource/io.proto\x12\x1e\x61i.stigmer.commons.apiresource\x1a\x46\x61i/stigmer/commons/apiresource/apiresourcekind/api_resource_kind.proto\x1a)ai/stigmer/commons/apiresource/enum.proto\x1a\'ai/stigmer/commons/rpc/pagination.proto\x1a\x1b\x62uf/validate/validate.proto\"-\n\rApiResourceId\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\"\x80\x01\n\x16\x41piResourceDeleteInput\x12\'\n\x0bresource_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\nresourceId\x12\'\n\x0fversion_message\x18\x02 \x01(\tR\x0eversionMessage\x12\x14\n\x05\x66orce\x18\x03 \x01(\x08R\x05\x66orce\"U\n\x1d\x41piResourceByOrgBySlugRequest\x12\x18\n\x03org\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x03org\x12\x1a\n\x04slug\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04slug\"\xbb\x01\n\x17\x46indApiResourcesRequest\x12\x18\n\x03org\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x03org\x12\x12\n\x04kind\x18\x03 \x01(\tR\x04kind\x12\x34\n\x04page\x18\x04 \x01(\x0b\x32 .ai.stigmer.commons.rpc.PageInfoR\x04page\x12\x1f\n\x0bpage_number\x18\x05 \x01(\x05R\npageNumber\x12\x1b\n\tpage_size\x18\x06 \x01(\x05R\x08pageSize\"\xa3\x01\n\x15UpdateVisibilityInput\x12\'\n\x0bresource_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\nresourceId\x12\x61\n\nvisibility\x18\x02 \x01(\x0e\x32\x35.ai.stigmer.commons.apiresource.ApiResourceVisibilityB\n\xbaH\x07\x82\x01\x04\x10\x01 \x00R\nvisibility\"\xa0\x02\n\x14\x41piResourceReference\x12/\n\x03org\x18\x01 \x01(\tB\x1d\xbaH\x1ar\x18\x18?2\x14^$|^[a-z][a-z0-9-]*$R\x03org\x12S\n\x04kind\x18\x02 \x01(\x0e\x32?.ai.stigmer.commons.apiresource.apiresourcekind.ApiResourceKindR\x04kind\x12\x33\n\x04slug\x18\x03 \x01(\tB\x1f\xbaH\x1cr\x17\x10\x01\x18?2\x11^[a-z][a-z0-9-]*$\xc8\x01\x01R\x04slug\x12M\n\x07version\x18\x04 \x01(\tB3\xbaH0r.2,^$|^latest$|^[a-zA-Z0-9._-]+$|^[a-f0-9]{64}$R\x07versionB\xc9\x01\n\"com.ai.stigmer.commons.apiresourceB\x07IoProtoP\x01\xa2\x02\x04\x41SCA\xaa\x02\x1e\x41i.Stigmer.Commons.Apiresource\xca\x02\x1e\x41i\\Stigmer\\Commons\\Apiresource\xe2\x02*Ai\\Stigmer\\Commons\\Apiresource\\GPBMetadata\xea\x02!Ai::Stigmer::Commons::Apiresourceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.commons.apiresource.io_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.ai.stigmer.commons.apiresourceB\007IoProtoP\001\242\002\004ASCA\252\002\036Ai.Stigmer.Commons.Apiresource\312\002\036Ai\\Stigmer\\Commons\\Apiresource\342\002*Ai\\Stigmer\\Commons\\Apiresource\\GPBMetadata\352\002!Ai::Stigmer::Commons::Apiresource'
  _globals['_APIRESOURCEID'].fields_by_name['value']._loaded_options = None
  _globals['_APIRESOURCEID'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_APIRESOURCEDELETEINPUT'].fields_by_name['resource_id']._loaded_options = None
  _globals['_APIRESOURCEDELETEINPUT'].fields_by_name['resource_id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_APIRESOURCEBYORGBYSLUGREQUEST'].fields_by_name['org']._loaded_options = None
  _globals['_APIRESOURCEBYORGBYSLUGREQUEST'].fields_by_name['org']._serialized_options = b'\272H\003\310\001\001'
  _globals['_APIRESOURCEBYORGBYSLUGREQUEST'].fields_by_name['slug']._loaded_options = None
  _globals['_APIRESOURCEBYORGBYSLUGREQUEST'].fields_by_name['slug']._serialized_options = b'\272H\003\310\001\001'
  _globals['_FINDAPIRESOURCESREQUEST'].fields_by_name['org']._loaded_options = None
  _globals['_FINDAPIRESOURCESREQUEST'].fields_by_name['org']._serialized_options = b'\272H\003\310\001\001'
  _globals['_UPDATEVISIBILITYINPUT'].fields_by_name['resource_id']._loaded_options = None
  _globals['_UPDATEVISIBILITYINPUT'].fields_by_name['resource_id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_UPDATEVISIBILITYINPUT'].fields_by_name['visibility']._loaded_options = None
  _globals['_UPDATEVISIBILITYINPUT'].fields_by_name['visibility']._serialized_options = b'\272H\007\202\001\004\020\001 \000'
  _globals['_APIRESOURCEREFERENCE'].fields_by_name['org']._loaded_options = None
  _globals['_APIRESOURCEREFERENCE'].fields_by_name['org']._serialized_options = b'\272H\032r\030\030?2\024^$|^[a-z][a-z0-9-]*$'
  _globals['_APIRESOURCEREFERENCE'].fields_by_name['slug']._loaded_options = None
  _globals['_APIRESOURCEREFERENCE'].fields_by_name['slug']._serialized_options = b'\272H\034r\027\020\001\030?2\021^[a-z][a-z0-9-]*$\310\001\001'
  _globals['_APIRESOURCEREFERENCE'].fields_by_name['version']._loaded_options = None
  _globals['_APIRESOURCEREFERENCE'].fields_by_name['version']._serialized_options = b'\272H0r.2,^$|^latest$|^[a-zA-Z0-9._-]+$|^[a-f0-9]{64}$'
  _globals['_APIRESOURCEID']._serialized_start=260
  _globals['_APIRESOURCEID']._serialized_end=305
  _globals['_APIRESOURCEDELETEINPUT']._serialized_start=308
  _globals['_APIRESOURCEDELETEINPUT']._serialized_end=436
  _globals['_APIRESOURCEBYORGBYSLUGREQUEST']._serialized_start=438
  _globals['_APIRESOURCEBYORGBYSLUGREQUEST']._serialized_end=523
  _globals['_FINDAPIRESOURCESREQUEST']._serialized_start=526
  _globals['_FINDAPIRESOURCESREQUEST']._serialized_end=713
  _globals['_UPDATEVISIBILITYINPUT']._serialized_start=716
  _globals['_UPDATEVISIBILITYINPUT']._serialized_end=879
  _globals['_APIRESOURCEREFERENCE']._serialized_start=882
  _globals['_APIRESOURCEREFERENCE']._serialized_end=1170
# @@protoc_insertion_point(module_scope)



import datetime

from ai.stigmer.commons.apiresource import status_pb2 as _status_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ValidationState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    validation_state_unspecified: _ClassVar[ValidationState]
    valid: _ClassVar[ValidationState]
    invalid: _ClassVar[ValidationState]

class DiscoverySource(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    discovery_source_unspecified: _ClassVar[DiscoverySource]
    seedpack: _ClassVar[DiscoverySource]
    cli: _ClassVar[DiscoverySource]
    agent_runner: _ClassVar[DiscoverySource]
validation_state_unspecified: ValidationState
valid: ValidationState
invalid: ValidationState
discovery_source_unspecified: DiscoverySource
seedpack: DiscoverySource
cli: DiscoverySource
agent_runner: DiscoverySource

class McpServerStatus(_message.Message):
    __slots__ = ("validation_state", "validation_message", "discovered_capabilities", "audit")
    VALIDATION_STATE_FIELD_NUMBER: _ClassVar[int]
    VALIDATION_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    DISCOVERED_CAPABILITIES_FIELD_NUMBER: _ClassVar[int]
    AUDIT_FIELD_NUMBER: _ClassVar[int]
    validation_state: ValidationState
    validation_message: str
    discovered_capabilities: DiscoveredCapabilities
    audit: _status_pb2.ApiResourceAudit
    def __init__(self, validation_state: _Optional[_Union[ValidationState, str]] = ..., validation_message: _Optional[str] = ..., discovered_capabilities: _Optional[_Union[DiscoveredCapabilities, _Mapping]] = ..., audit: _Optional[_Union[_status_pb2.ApiResourceAudit, _Mapping]] = ...) -> None: ...

class DiscoveredCapabilities(_message.Message):
    __slots__ = ("tools", "resource_templates", "last_discovered_at", "discovered_by")
    TOOLS_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_TEMPLATES_FIELD_NUMBER: _ClassVar[int]
    LAST_DISCOVERED_AT_FIELD_NUMBER: _ClassVar[int]
    DISCOVERED_BY_FIELD_NUMBER: _ClassVar[int]
    tools: _containers.RepeatedCompositeFieldContainer[DiscoveredTool]
    resource_templates: _containers.RepeatedCompositeFieldContainer[DiscoveredResourceTemplate]
    last_discovered_at: _timestamp_pb2.Timestamp
    discovered_by: DiscoverySource
    def __init__(self, tools: _Optional[_Iterable[_Union[DiscoveredTool, _Mapping]]] = ..., resource_templates: _Optional[_Iterable[_Union[DiscoveredResourceTemplate, _Mapping]]] = ..., last_discovered_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., discovered_by: _Optional[_Union[DiscoverySource, str]] = ...) -> None: ...

class DiscoveredTool(_message.Message):
    __slots__ = ("name", "description", "input_schema")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    INPUT_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    input_schema: _struct_pb2.Struct
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., input_schema: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class DiscoveredResourceTemplate(_message.Message):
    __slots__ = ("uri_template", "name", "description", "mime_type")
    URI_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    MIME_TYPE_FIELD_NUMBER: _ClassVar[int]
    uri_template: str
    name: str
    description: str
    mime_type: str
    def __init__(self, uri_template: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., mime_type: _Optional[str] = ...) -> None: ...
